pub struct TypeResolver<'i, 'c> { /* private fields */ }Expand description
A basic type resolver designed to initialize types at the beginning of type checking. This resolver is intentionally simple and acts as a “bootstrap” to get type information that can later be narrowed down for more precise type inference.
While this type resolver is limited in detail, it provides enough information for initial analysis and bootstrapping. However, it requires a subsequent pass to refine types.
Capabilities
This resolver can completely evaluate constant expressions in most cases and produce a type
with a known value, such as Value::Float(16.5) for expressions like ((12 / 2) + 5) * 1.5.
Improved Type Resolution with Codebase Context
If a codebase is available, this resolver can leverage it to retrieve types of functions, methods, and constants, making it slightly more powerful in providing initial type information.
Implementations
Sourceimpl<'i, 'c> TypeResolver<'i, 'c>
impl<'i, 'c> TypeResolver<'i, 'c>
pub fn new( interner: &'i ThreadedInterner, source: &'c Source, names: &'c ResolvedNames, codebase: Option<&'c CodebaseReflection>, ) -> Self
pub fn resolve(&self, expression: &Expression) -> TypeKind